import React from 'react';
import classnames from 'classnames';
import { useId } from '@highlight-ui/utils-hooks';
import { parseMetadata, noop } from '@highlight-ui/utils-commons';
import { Stack, Inline } from '@highlight-ui/layout';
import { ToggleInput, ToggleInputLabel, ToggleInputSubLabel } from '@highlight-ui/toggle-input';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];
      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }
    return t;
  };
  return __assign.apply(this, arguments);
};
function __rest(s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
}
var styles = {
  "radioButtonContainer": "RadioButton-module__D1jKejRM__v5-1-2"
};
var Circle = /*#__PURE__*/React.createElement("svg", {
  xmlns: "http://www.w3.org/2000/svg",
  width: "6",
  height: "6",
  fill: "none"
}, /*#__PURE__*/React.createElement("rect", {
  width: "5.6",
  height: "5.6",
  x: ".2",
  y: ".2",
  fill: "#fff",
  rx: "2.8"
}));
var RadioButton = /*#__PURE__*/React.forwardRef(function (_a, ref) {
  var label = _a.label,
    subLabel = _a.subLabel,
    className = _a.className,
    metadata = _a.metadata,
    id = _a.id,
    disabled = _a.disabled,
    tooltipContent = _a.tooltipContent,
    tooltipMouseOutDelay = _a.tooltipMouseOutDelay,
    _b = _a.tone,
    tone = _b === void 0 ? 'default' : _b,
    radioProps = __rest(_a, ["label", "subLabel", "className", "metadata", "id", "disabled", "tooltipContent", "tooltipMouseOutDelay", "tone"]);
  var generatedId = useId('radioButton-');
  var inputId = id || generatedId;
  return /*#__PURE__*/React.createElement("div", __assign({
    className: classnames(styles.radioButtonContainer, className)
  }, parseMetadata(metadata)), /*#__PURE__*/React.createElement(ToggleInput, __assign({
    ref: ref,
    id: inputId,
    type: "radio",
    disabled: disabled,
    metadata: metadata
  }, radioProps)), /*#__PURE__*/React.createElement(Stack, {
    space: "spacing-1"
  }, /*#__PURE__*/React.createElement(ToggleInputLabel, {
    inputId: inputId,
    label: label,
    disabled: disabled,
    metadata: metadata,
    tooltipContent: tooltipContent,
    tooltipMouseOutDelay: tooltipMouseOutDelay,
    tone: tone,
    icon: Circle
  }), label && subLabel && /*#__PURE__*/React.createElement(ToggleInputSubLabel, {
    inputId: inputId,
    subLabel: subLabel,
    disabled: disabled,
    metadata: metadata
  })));
});
var RadioButtonGroup = /*#__PURE__*/React.forwardRef(function (_a, ref) {
  var className = _a.className,
    metadata = _a.metadata,
    name = _a.name,
    _b = _a.disabled,
    disabled = _b === void 0 ? false : _b,
    _c = _a.orientation,
    orientation = _c === void 0 ? 'vertical' : _c,
    options = _a.options,
    value = _a.value,
    _d = _a.onChange,
    onChange = _d === void 0 ? noop : _d;
  var generatedName = useId('radioButtonGroup-');
  var radioButtonGroupName = name || generatedName;
  var Layout = orientation === 'horizontal' ? Inline : Stack;
  return /*#__PURE__*/React.createElement(Layout, {
    ref: ref,
    space: orientation === 'horizontal' ? 'spacing-5' : 'spacing-3',
    className: className,
    metadata: metadata
  }, options.map(function (option) {
    return /*#__PURE__*/React.createElement(RadioButton, {
      key: "".concat(option.value, "-").concat(radioButtonGroupName),
      metadata: option.metadata,
      className: option.className,
      id: option.id,
      label: option.label,
      subLabel: option.subLabel,
      value: option.value,
      disabled: disabled || option.disabled,
      checked: value === option.value,
      name: radioButtonGroupName,
      onChange: function () {
        return onChange(option);
      },
      tooltipContent: option.tooltipContent,
      tooltipMouseOutDelay: option.tooltipMouseOutDelay,
      tone: option.tone
    });
  }));
});
export { RadioButton, RadioButtonGroup };
//# sourceMappingURL=index.js.map
